@@ -16,6 +16,23 @@ class Feed : public RootItem {
     Q_OBJECT
 
   public:
+    struct ArticleIgnoreLimit {
+        // Ignoring articles.
+        bool m_avoidOldArticles = false;
+        bool m_addAnyArticlesToDb = false;
+        QDateTime m_dtToAvoid = QDateTime();
+        int m_hoursToAvoid = 0;
+
+        // Limitting articles.
+        bool m_customizeLimitting = false;
+        int m_keepCountOfArticles = 0;
+        bool m_doNotRemoveStarred = true;
+        bool m_doNotRemoveUnread = true;
+        bool m_moveToBinDontPurge = false;
+
+        static ArticleIgnoreLimit fromSettings();
+    };
+
     // Specifies the auto-download strategy for the feed.
     enum class AutoUpdateType {
       DontAutoUpdate = 0,
@@ -91,11 +108,11 @@ class Feed : public RootItem {
     bool isRtl() const;
     void setIsRtl(bool rtl);
 
-    bool addAnyDatetimeArticles() const;
-    void setAddAnyDatetimeArticles(bool add_any_articles);
+    bool removeUnwantedArticles(QSqlDatabase& db);
 
-    QDateTime datetimeToAvoid() const;
-    void setDatetimeToAvoid(const QDateTime& dt);
+    ArticleIgnoreLimit& articleIgnoreLimit();
+    const ArticleIgnoreLimit& articleIgnoreLimit() const;
+    void setArticleIgnoreLimit(const ArticleIgnoreLimit& ignore_limit);
 
   public slots:
     virtual void updateCounts(bool including_total_count);
@@ -115,9 +132,13 @@ class Feed : public RootItem {
     bool m_isQuiet;
     bool m_openArticlesDirectly;
     bool m_isRtl;
-    bool m_addAnyDatetimeArticles;
 
-    QDateTime m_datetimeToAvoid;
+    // NOTE: These are used to filter out older articles
+    // than needed. Either absolute value is given (date/time)
+    // or relative value given in minutes.
+    // Amount
+    ArticleIgnoreLimit m_articleIgnoreLimit;
+
     int m_totalCount{};
     int m_unreadCount{};
     QList<QPointer<MessageFilter>> m_messageFilters;
@@ -125,5 +146,6 @@ class Feed : public RootItem {
 
 Q_DECLARE_METATYPE(Feed::AutoUpdateType)
 Q_DECLARE_METATYPE(Feed::Status)
+Q_DECLARE_METATYPE(Feed::ArticleIgnoreLimit)
 
 #endif // FEED_H
